#!/bin/bash
# AWSに直接コピペすると文字化けするので注意

# hostname of main server
BM_DOMAIN=vr.binaural.me
hostname=rooms.${BM_DOMAIN}

# function wait for another apt process. 
function wait_for_dpkg_lock {
  # check for a lock on dpkg (another installation is running)
  lsof /var/lib/dpkg/lock > /dev/null
  dpkg_is_locked="$?"
  if [ "$dpkg_is_locked" == "0" ]; then
    echo "Waiting for another installation to finish"
    sleep 5
    wait_for_dpkg_lock
  fi
  rm /var/lib/dpkg/lock-frontend
  rm /var/lib/dpkg/lock
}
echo wait_for_dpkg_lock
wait_for_dpkg_lock

# function to get hostname of main server. 
function getHostname() {
    ipaddr=
    while [ "$ipaddr" = "" ]; do
        ipaddr=`host -ta ${hostname}`
        ipaddr=${ipaddr##* }
        if [ "$ipaddr" = "`curl 169.254.169.254/latest/meta-data/public-ipv4`" ]; then break; fi
        #if [ "$ipaddr" = "13.230.218.86" ]; then break; fi
        ipaddr=
        sleep 3s;
    done
}

echo apt update 
sudo apt-get -y update

# assign public IP
echo install awscli
sleep 3
wait_for_dpkg_lock
rm /var/lib/dpkg/lock-frontend
rm /var/lib/dpkg/lock
apt-get install -y awscli
sleep 3
wait_for_dpkg_lock
rm /var/lib/dpkg/lock-frontend
rm /var/lib/dpkg/lock
apt-get install -y awscli


EC2_INSTANCE_ID=`curl -s http://169.254.169.254/latest/meta-data/instance-id`
aws ec2 associate-address --instance-id $EC2_INSTANCE_ID --public-ip 18.178.81.7 --region ap-northeast-1

echo install git and npm
#sudo apt-get -y install emacs
wait_for_dpkg_lock
sudo apt-get -y install git
sleep 1
sudo apt-get -y install unzip
curl -fsSL https://deno.land/x/install/install.sh | sh
sudo apt-get -y install nodejs npm
sudo npm install pm2 -g

sudo apt-get -y install nginx

getHostname
if [ "`curl -LI https://binaural.me/public_packages/uploader/vr/${hostname}_fullchain.pem -o /dev/null -w '%{http_code}\n' -s`" = "200" ]; then
    sudo mkdir -p /etc/letsencrypt/live/${hostname}
    sudo curl --output /etc/letsencrypt/live/${hostname}/fullchain.pem https://binaural.me/public_packages/uploader/vr/${hostname}_fullchain.pem
    sudo curl --output /etc/letsencrypt/live/${hostname}/privkey.pem https://binaural.me/public_packages/uploader/vr/${hostname}_privkey.pem
else
    # get cert by certbot
    sudo snap install core; sudo snap refresh core
    sudo apt-get remove certbot
    sudo snap install --classic certbot
    sudo ln -s /snap/bin/certbot /usr/bin/certbot
    sudo certbot --nginx --non-interactive --agree-tos --email hasevr@gs.haselab.net --domains $hostname

    #upload cert 
    sudo curl -X POST -H "Content-Type: multipart/form-data" -F "do_upload=true" -F "userfile=@/etc/letsencrypt/live/${hostname}/fullchain.pem;filename=${hostname}_fullchain.pem" https://binaural.me/public_packages/uploader/vr/index.php 
    sudo curl -X POST -H "Content-Type: multipart/form-data" -F "do_upload=true" -F "userfile=@/etc/letsencrypt/live/${hostname}/privkey.pem;filename=${hostname}_privkey.pem" https://binaural.me/public_packages/uploader/vr/index.php 
fi

/etc/init.d/nginx stop

#Install and start roomInfoServer
cd
git clone https://github.com/BinauralMeet/roomInfoServer
cd roomInfoServer
ln -s /etc/letsencrypt/live/${hostname}/fullchain.pem host.crt
ln -s /etc/letsencrypt/live/${hostname}/privkey.pem host.key
echo {>>config.json
echo    \"port\": 443,>>config.json
echo    \"tls\": true>>config.json
echo }>>config.json
#/root/.deno/bin/deno run --allow-net --allow-read bmRoomInfoServer.ts>bmRoomInfoServer.log
pm2 start bmRoomInfoServer.ts --interpreter="/root/.deno/bin/deno" --interpreter-args="run --allow-net --allow-read"
